pub struct DialectBinding {
pub input: DialectDescriptor,
pub output: DialectDescriptor,
pub negotiation: DialectNegotiation,
}Expand description
Immutable input/output dialect pair for one opened connection.
Fields
input: DialectDescriptorBytes written to the external system use this dialect.
output: DialectDescriptorBytes read from the external system use this dialect.
negotiation: DialectNegotiationWhether dialects were fixed or negotiated.
Implementations
Sourceimpl DialectBinding
impl DialectBinding
Sourcepub fn fixed(dialect: DialectDescriptor) -> Self
pub fn fixed(dialect: DialectDescriptor) -> Self
Fixed identical input/output dialect.
Sourcepub fn negotiated(dialect: DialectDescriptor) -> Self
pub fn negotiated(dialect: DialectDescriptor) -> Self
Negotiated identical input/output dialect (frozen at open).